@@ -76,7 +76,8 @@ class Gaia:
             self.project = self.get_project()
         client = SecretManagerServiceClient()
         secret_path = client.secret_version_path(self.project, name, "latest")
-        return client.access_secret_version(secret_path).payload.data.decode("utf-8")
+        request = {"name": secret_path}
+        return client.access_secret_version(request=request).payload.data.decode("utf-8")
 
     def get_settings(self, name):
         """Return the configuration settings for a specific service name."""
