@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 """Gaia Auth class file."""
+import json
 
 
 class Auth:
@@ -36,6 +37,14 @@ class Auth:
             verbose=self.gaia.verbose,
         )
 
+    def dialpad(self):
+        """Return an authorized Dialpad instance for gaia."""
+        from bits.dialpad import Dialpad
+        settings = self.gaia.get_settings("dialpad")
+        return Dialpad(
+            token=self.gaia.get_secret(settings.get("token_name")),
+        )
+
     def gaia_sftp(self):
         """Return an authorized SFTP instance for gaia."""
         from bits.sftp import SFTP
@@ -47,11 +56,47 @@ class Auth:
             key=self.gaia.get_secret(settings.get("key_name")),
         )
 
+    def github(self):
+        """Return a authorized Github instance for gaia."""
+        from bits.github import GitHub
+        settings = self.gaia.get_settings("github")
+        return GitHub(
+            token=self.gaia.get_secret(settings.get("token_name")),
+            org=settings.get("organization"),
+            owner_team=settings.get("owner_team"),
+            role_team=settings.get("role_team"),
+        )
+
     def google(self, scopes):
         """Return an authorized Google instance for gaia."""
         from bits.google import Google
         return Google(scopes=scopes)
 
+    def google_admin(self, scopes):
+        """Return an authorized Google instance for gaia."""
+        from bits.google import Google
+        settings = self.gaia.get_settings("google")
+        return Google(
+            scopes=scopes,
+            service_account_info=json.loads(self.gaia.get_secret(settings.get("key_name"))),
+        )
+
+    def pagerduty(self):
+        """Return an authorized PagerDuty instance for gaia."""
+        from pdpyras import APISession
+        settings = self.gaia.get_settings("pagerduty")
+        return APISession(self.gaia.get_secret(settings.get("key_name")))
+
+    def quay(self):
+        """Return am authorized Quay instance for gaia."""
+        from bits.quay import Quay
+        settings = self.gaia.get_settings("quay")
+        return Quay(
+            token=self.gaia.get_secret(settings.get("token_name")),
+            orgname=settings.get("organization"),
+            role_team=settings.get("role_team"),
+        )
+
     def people_mysql(self):
         """Return an authorized MySQL instance for People."""
         from bits.mysql import MySQL
@@ -81,9 +126,9 @@ class Auth:
 
     def slack_user(self):
         """Return an authorized Slack Workspace instance with a user token."""
-        from bits.slack import Slack
+        from slack_sdk import WebClient
         settings = self.gaia.get_settings("slack_broadinstitute")
-        return Slack(
+        return WebClient(
             token=self.gaia.get_secret(settings.get("user_token_name")),
         )
 
